console

package
v0.1.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 2, 2026 License: AGPL-3.0 Imports: 23 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func FuzzySelect

func FuzzySelect(title string, items []fuzzyItem) (string, bool)

FuzzySelect opens an interactive fuzzy finder and returns the selected item name. Returns empty string and false if aborted.

func Run

func Run() error

Run starts the interactive console.

func RunWith added in v0.1.4

func RunWith(mod sdk.Exploit) error

RunWith starts the interactive console with an optional pre-selected module.

Types

type Console

type Console struct {
	// contains filtered or unexported fields
}

Console is the interactive REPL.

Jump to